==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/SafeTLSConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SafeTLSConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfig,io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigBuilder>{
  public SafeTLSConfigBuilder() {
    this(false);
  }
  public SafeTLSConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new SafeTLSConfig(), validationEnabled);
  }
  public SafeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SafeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SafeTLSConfig(), validationEnabled);
  }
  public SafeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfig instance) {
    this(fluent, instance, false);
  }
  public SafeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withCert(instance.getCert()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withKeySecret(instance.getKeySecret()); 
    fluent.withServerName(instance.getServerName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SafeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfig instance) {
    this(instance,false);
  }
  public SafeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withCert(instance.getCert()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withKeySecret(instance.getKeySecret()); 
    this.withServerName(instance.getServerName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.SafeTLSConfig build() {
    SafeTLSConfig buildable = new SafeTLSConfig(fluent.getCa(),fluent.getCert(),fluent.getInsecureSkipVerify(),fluent.getKeySecret(),fluent.getServerName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SafeTLSConfigBuilder that = (SafeTLSConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/SafeTLSConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SafeTLSConfigBuilder extends SafeTLSConfigFluentImpl<SafeTLSConfigBuilder> implements VisitableBuilder<SafeTLSConfig,SafeTLSConfigBuilder>{
  public SafeTLSConfigBuilder() {
    this(false);
  }
  public SafeTLSConfigBuilder(Boolean validationEnabled) {
    this(new SafeTLSConfig(), validationEnabled);
  }
  public SafeTLSConfigBuilder(SafeTLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SafeTLSConfigBuilder(SafeTLSConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SafeTLSConfig(), validationEnabled);
  }
  public SafeTLSConfigBuilder(SafeTLSConfigFluent<?> fluent,SafeTLSConfig instance) {
    this(fluent, instance, false);
  }
  public SafeTLSConfigBuilder(SafeTLSConfigFluent<?> fluent,SafeTLSConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withCert(instance.getCert()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withKeySecret(instance.getKeySecret()); 
    fluent.withServerName(instance.getServerName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SafeTLSConfigBuilder(SafeTLSConfig instance) {
    this(instance,false);
  }
  public SafeTLSConfigBuilder(SafeTLSConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withCert(instance.getCert()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withKeySecret(instance.getKeySecret()); 
    this.withServerName(instance.getServerName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SafeTLSConfigFluent<?> fluent;
  Boolean validationEnabled;
  public SafeTLSConfig build() {
    SafeTLSConfig buildable = new SafeTLSConfig(fluent.getCa(),fluent.getCert(),fluent.getInsecureSkipVerify(),fluent.getKeySecret(),fluent.getServerName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
